dispMUA.init_overlay = () =>
{
  if ( dispMUA.bundle != null )
  {
    return ;
  }

  dispMUA.bundle = document.getElementById ( "dispmua-strings" ) ;

  dispMUA.loadJSON ( "dispmua-database.json" ) ;

  var listener = {} ;
  listener.onStartHeaders = () => {} ;
  listener.onEndHeaders = dispMUA.loadHeaderData ;
  gMessageListeners.push ( listener ) ;

  var elem = document.getElementById ( "mailContext" ) ;

  if ( elem )
  {
    elem.addEventListener ( "popupshowing" , dispMUA.checktextPopup , false ) ;
  }

  dispMUA.loadMUAOverlayFile() ;
}

window.addEventListener ( "messagepane-loaded" , dispMUA.init_overlay , true ) ;
